@@ -70,14 +70,14 @@ int32_t SPVM__Sys__Socket__inet_aton(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_cp = stack[0].oval;
   
+  void* obj_inp = stack[1].oval;
+  
   if (!obj_cp) {
     return env->die(env, stack, "The address string $cp must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   const char* cp = env->get_chars(env, stack, obj_cp);
   
-  void* obj_inp = stack[1].oval;
-  
   if (!obj_inp) {
     return env->die(env, stack, "The address data structure $inp must be defined.", __func__, FILE_NAME, __LINE__);
   }
@@ -149,20 +149,20 @@ int32_t SPVM__Sys__Socket__inet_pton(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t af = stack[0].ival;
   
+  void* obj_src = stack[1].oval;
+  
+  void* obj_dst = stack[2].oval;
+  
   if (!(af == AF_INET || af == AF_INET6)) {
     return env->die(env, stack, "The address family $af must be AF_INET or AF_INET6.", __func__, FILE_NAME, __LINE__);
   }
   
-  void* obj_src = stack[1].oval;
-  
   if (!obj_src) {
     return env->die(env, stack, "The address string $src must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   const char* src = env->get_chars(env, stack, obj_src);
   
-  void* obj_dst = stack[2].oval;
-  
   if (!obj_dst) {
     return env->die(env, stack, "The address data structure $dst must be defined.", __func__, FILE_NAME, __LINE__);
   }
@@ -201,30 +201,28 @@ int32_t SPVM__Sys__Socket__inet_pton(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__Socket__inet_ntop(SPVM_ENV* env, SPVM_VALUE* stack) {
   
-  // The address family
   int32_t af = stack[0].ival;
   
+  void* obj_src = stack[1].oval;
+  
+  void* obj_dst = stack[2].oval;
+  
+  int32_t size = stack[3].ival;
+  
   if (!(af == AF_INET || af == AF_INET6)) {
     return env->die(env, stack, "The address family $af must be AF_INET or AF_INET6.", __func__, FILE_NAME, __LINE__);
   }
   
-  // The input address
-  void* obj_src = stack[1].oval;
   if (!obj_src) {
     return env->die(env, stack, "The address data structure $src must be defined.", __func__, FILE_NAME, __LINE__);
   }
   void* src = env->get_pointer(env, stack, obj_src);
   
-  // The output address
-  void* obj_dst = stack[2].oval;
   if (!obj_dst) {
     return env->die(env, stack, "The address string $dst must be defined.", __func__, FILE_NAME, __LINE__);
   }
   char* dst = (char*)env->get_chars(env, stack, obj_dst);
   
-  // The size of the output address
-  int32_t size = stack[3].ival;
-  
   const char* dst_ret = inet_ntop(af, src, dst, size);
   
   if (!dst_ret) {
@@ -315,13 +313,17 @@ int32_t SPVM__Sys__Socket__accept(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_addr = stack[1].oval;
   
+  int32_t* addrlen_ref = stack[2].iref;
+  
   if (!obj_addr) {
     return env->die(env, stack, "The client address $addr must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   struct sockaddr* addr = env->get_pointer(env, stack, obj_addr);
   
-  int32_t* addrlen_ref = stack[2].iref;
+  if (!addrlen_ref) {
+    return env->die(env, stack, "The reference of the output address length $addrlen_ref must be defined.", __func__, FILE_NAME, __LINE__);
+  }
   
   socklen_t sl_addrlen = *addrlen_ref;
   
@@ -435,6 +437,16 @@ int32_t SPVM__Sys__Socket__recvfrom(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_buf = stack[1].oval;
   
+  int32_t len = stack[2].ival;
+  
+  int32_t flags = stack[3].ival;
+  
+  void* obj_src_addr = stack[4].oval;
+  
+  int32_t* addrlen_ref = stack[5].iref;
+  
+  int32_t buf_offset = stack[6].ival;
+  
   if (!obj_buf) {
     return env->die(env, stack, "The buffer $buf must be defined.", __func__, FILE_NAME, __LINE__);
   }
@@ -442,20 +454,14 @@ int32_t SPVM__Sys__Socket__recvfrom(SPVM_ENV* env, SPVM_VALUE* stack) {
   char* buf = (char*)env->get_chars(env, stack, obj_buf);
   int32_t buf_length = env->length(env, stack, obj_buf);
   
-  int32_t len = stack[2].ival;
-  
-  int32_t flags = stack[3].ival;
-  
-  void* obj_src_addr = stack[4].oval;
-  
   struct sockaddr* src_addr = NULL;
   if (obj_src_addr) {
     src_addr = env->get_pointer(env, stack, obj_src_addr);
   }
   
-  int32_t* addrlen_ref = stack[5].iref;
-  
-  int32_t buf_offset = stack[6].ival;
+  if (!addrlen_ref) {
+    return env->die(env, stack, "The reference of the output address length $addrlen_ref must be defined.", __func__, FILE_NAME, __LINE__);
+  }
   
   if (!(len <= buf_length - buf_offset)) {
     return env->die(env, stack, "The data length $len must be less than the length of the buffer $buf minus the buffer offset $buf_offset.", __func__, FILE_NAME, __LINE__);
@@ -482,6 +488,11 @@ int32_t SPVM__Sys__Socket__send(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_buf = stack[1].oval;
   
+  int32_t len = stack[2].ival;
+  
+  int32_t flags = stack[3].ival;
+  
+  int32_t buf_offset = stack[4].ival;
   if (!obj_buf) {
     return env->die(env, stack, "The buffer $buf must be defined.", __func__, FILE_NAME, __LINE__);
   }
@@ -489,11 +500,6 @@ int32_t SPVM__Sys__Socket__send(SPVM_ENV* env, SPVM_VALUE* stack) {
   const char* buf = env->get_chars(env, stack, obj_buf);
   int32_t buf_length = env->length(env, stack, obj_buf);
   
-  int32_t len = stack[2].ival;
-  
-  int32_t flags = stack[3].ival;
-  
-  int32_t buf_offset = stack[4].ival;
   if (!(len <= buf_length - buf_offset)) {
     return env->die(env, stack, "The data length $len must be less than the length of the buffer $buf minus the buffer offset $buf_offset.", __func__, FILE_NAME, __LINE__);
   }
@@ -516,6 +522,12 @@ int32_t SPVM__Sys__Socket__sendto(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_buf = stack[1].oval;
   
+  int32_t len = stack[2].ival;
+  
+  int32_t flags = stack[3].ival;
+  
+  void* obj_addr = stack[4].oval;
+  
   if (!obj_buf) {
     return env->die(env, stack, "The buffer $buf must be defined.", __func__, FILE_NAME, __LINE__);
   }
@@ -523,12 +535,6 @@ int32_t SPVM__Sys__Socket__sendto(SPVM_ENV* env, SPVM_VALUE* stack) {
   const char* buf = env->get_chars(env, stack, obj_buf);
   int32_t buf_length = env->length(env, stack, obj_buf);
   
-  int32_t len = stack[2].ival;
-  
-  int32_t flags = stack[3].ival;
-  
-  void* obj_addr = stack[4].oval;
-  
   const struct sockaddr* addr = NULL;
   
   if (obj_addr) {
@@ -560,13 +566,17 @@ int32_t SPVM__Sys__Socket__getpeername(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_addr = stack[1].oval;
   
+  int32_t* addrlen_ref = stack[2].iref;
+  
   if (!obj_addr) {
     return env->die(env, stack, "The socket address $addr must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   struct sockaddr* addr = env->get_pointer(env, stack, obj_addr);
   
-  int32_t* addrlen_ref = stack[2].iref;
+  if (!addrlen_ref) {
+    return env->die(env, stack, "The reference of the output address length $addrlen_ref must be defined.", __func__, FILE_NAME, __LINE__);
+  }
   
   socklen_t sl_addrlen = *addrlen_ref;
   
@@ -590,13 +600,17 @@ int32_t SPVM__Sys__Socket__getsockname(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_addr = stack[1].oval;
   
+  int32_t* addrlen_ref = stack[2].iref;
+  
   if (!obj_addr) {
     return env->die(env, stack, "The socket address $addr must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   struct sockaddr* addr = env->get_pointer(env, stack, obj_addr);
   
-  int32_t* addrlen_ref = stack[2].iref;
+  if (!addrlen_ref) {
+    return env->die(env, stack, "The reference of the output address length $addrlen_ref must be defined.", __func__, FILE_NAME, __LINE__);
+  }
   
   socklen_t sl_addrlen = *addrlen_ref;
   
@@ -623,6 +637,9 @@ int32_t SPVM__Sys__Socket__getsockopt(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t optname = stack[2].ival;
   
   void* obj_optval = stack[3].oval;
+  
+  int32_t* optlen_ref = stack[4].iref;
+  
   char* optval = NULL;
   if (!obj_optval) {
     return env->die(env, stack, "The option value $optval must be defined.", __func__, FILE_NAME, __LINE__);
@@ -630,7 +647,6 @@ int32_t SPVM__Sys__Socket__getsockopt(SPVM_ENV* env, SPVM_VALUE* stack) {
   optval = (char*)env->get_chars(env, stack, obj_optval);
   int32_t optval_length = env->length(env, stack, obj_optval);
   
-  int32_t* optlen_ref = stack[4].iref;
   if (!(*optlen_ref >= 0)) {
     env->die(env, stack, "The length stored at index 0 of $optlen_ref must be greater than or equal to 0.", __func__, FILE_NAME, __LINE__);
   }
@@ -638,15 +654,15 @@ int32_t SPVM__Sys__Socket__getsockopt(SPVM_ENV* env, SPVM_VALUE* stack) {
     env->die(env, stack, "The length stored at index 0 of $optlen_ref must be less than or equal to the length of the option value $optval.", __func__, FILE_NAME, __LINE__);
   }
   
-  socklen_t socklen_t_optlen = *optlen_ref;
-  int32_t status = getsockopt(sockfd, level, optname, optval, &socklen_t_optlen);
+  socklen_t optlen_tmp = *optlen_ref;
+  int32_t status = getsockopt(sockfd, level, optname, optval, &optlen_tmp);
   
   if (status == -1) {
     env->die(env, stack, "[System Error]getsockopt() failed:%s.", spvm_socket_strerror(env, stack, spvm_socket_errno(), 0), __func__, FILE_NAME, __LINE__);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
-  *optlen_ref = socklen_t_optlen;
+  *optlen_ref = optlen_tmp;
   
   stack[0].ival = status;
   
@@ -662,6 +678,9 @@ int32_t SPVM__Sys__Socket__setsockopt(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t optname = stack[2].ival;
   
   void* obj_optval = stack[3].oval;
+  
+  socklen_t optlen = stack[4].ival;
+  
   char* optval = NULL;
   if (!obj_optval) {
     return env->die(env, stack, "The option value $optval must be defined.", __func__, FILE_NAME, __LINE__);
@@ -669,7 +688,6 @@ int32_t SPVM__Sys__Socket__setsockopt(SPVM_ENV* env, SPVM_VALUE* stack) {
   optval = (char*)env->get_chars(env, stack, obj_optval);
   int32_t optval_length = env->length(env, stack, obj_optval);
   
-  socklen_t optlen = stack[4].ival;
   if (!(optlen >= 0)) {
     env->die(env, stack, "The length stored at index 0 of $optlen_ref must be greater than or equal to 0.", __func__, FILE_NAME, __LINE__);
   }
@@ -738,26 +756,27 @@ int32_t SPVM__Sys__Socket__getaddrinfo(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_node = stack[0].oval;
   
+  void* obj_service = stack[1].oval;
+  
+  void* obj_hints = stack[2].oval;
+  
+  void* obj_res_array = stack[3].oval;
+  
   const char* node = NULL;
   if (obj_node) {
     node = env->get_chars(env, stack, obj_node);
   }
   
-  void* obj_service = stack[1].oval;
-  
   const char* service = NULL;
   if (obj_service) {
     service = env->get_chars(env, stack, obj_service);
   }
   
-  void* obj_hints = stack[2].oval;
-  
   struct addrinfo *hints = NULL;
   if (obj_hints) {
     hints = env->get_pointer(env, stack, obj_hints);
   }
   
-  void* obj_res_array = stack[3].oval;
   if (!obj_res_array) {
     return env->die(env, stack, "The array $res_ref to store a response must be defined.", __func__, FILE_NAME, __LINE__);
   }
@@ -796,32 +815,34 @@ int32_t SPVM__Sys__Socket__getnameinfo(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_sa = stack[0].oval;
   
+  int32_t salen = stack[1].ival;
+  
+  void* obj_host = stack[2].oval;
+  
+  int32_t hostlen = stack[3].ival;
+  
+  void* obj_serv = stack[4].oval;
+  
+  int32_t servlen = stack[5].ival;
+  
+  int32_t flags = stack[6].ival;
+  
   if (!obj_sa) {
     return env->die(env, stack, "The socket address $sa must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   const struct sockaddr* sa = env->get_pointer(env, stack, obj_sa);
   
-  int32_t salen = stack[1].ival;
-  
-  void* obj_host = stack[2].oval;
   char* host = NULL;
   if (obj_host) {
     host = (char*)env->get_chars(env, stack, obj_host);
   }
   
-  int32_t hostlen = stack[3].ival;
-  
-  void* obj_serv = stack[4].oval;
   char* serv = NULL;
   if (obj_serv) {
     serv = (char*)env->get_chars(env, stack, obj_serv);
   }
   
-  int32_t servlen = stack[5].ival;
-  
-  int32_t flags = stack[6].ival;
-  
   int32_t status = getnameinfo(sa, salen, host, hostlen, serv, servlen, flags);
   
   if (!(status == 0)) {
